# Don't Bullshit

## What can you do with dontbs
* Set the daily goal of your GitHub contributions
* Check your progress
* Don't do shit and watch how this stupid script insults you all day
* Reach your goal and get nothing

## Usage
```console
Usage: dontbs [OPTIONS] USERNAME

Options:
  --today          Today's contribution count.
  --this-week      This week's contribution count.
  --this-year      This year's contribution count.
  --current-level  Current level based on today's contribution count.
  --next-level     Minimum amount of contributions needed to level up.
  --streak         Streak of daily contributios.
  --goal INTEGER   Set your daily goal of contributions.
  --help           Show this message and exit.
```

## Installation
```console
pip install dontbs
```
